;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'efs-hooks '("efs"))
(custom-add-loads 'efs-gateways '("efs"))
(custom-add-loads 'efs-behavior '("efs"))
(custom-add-loads 'efs-programs '("efs"))
(custom-add-loads 'efs-auto-save '("efs"))
(custom-add-loads 'efs-parameters '("efs"))
(custom-add-loads 'files '("efs"))
(custom-add-loads 'efs '("efs"))

;;; custom-load.el ends here
